PyXMake Developer Guide: PyXMake.Build.Make.Sphinx Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.Sphinx Class Reference

Base class for all Sphinx build events. More...

Inheritance diagram for PyXMake.Build.Make.Sphinx:

## Public Member Functions
def | __init__ (self, args, kwargs)
def | Settings (self, kwargs)
def | create (self, kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
def | __init__ (self, BuildID, Srcs, scratch=os.getcwd(), msvsc='vs2015', stype='Fortran', verbose=0, args, kwargs)
def | __getstate__ (self)
def | __setstate__ (self, _dict)
def | AddIncludePath (self, includes)
def | AddDependencyPath (self, dependencies)
def | UseLibraries (self, libs)
def | SourcePath (self, path)
def | OutputPath (self, path, files="")
def | Environment (self, path, script="ifortvars.bat")
def | Preprocessing
def | Build (self, cmdstring)
def | Postprocessing (self, cmdstring='')
def | create (self)

## Public Attributes
| MakeObjectKind
| String identifier of current instance. More...
| path2exe
| Path to Sphinx executable. More...
| exe
| Executable of Sphinx. More...
| BuildOption
| Ordered dictionary containing all available options.
| incdirs
| Blank version of list containing library directories without initially specifying MKL. More...
| libdirs
| SPHINXOPTS
| SPHINXBUILD
| PAPER
| SOURCEDIR
| BUILDDIR
| TEMPDIR
| STATICEDIR
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid
| Base string of build object. More...
| srcs
| Source file or folders.
| stype
| Source file type.
| verbose
| Level of verbosity of the current build object. More...
| scrtdir
| Current scratch directory.
| srcdir
| Default search directory for source files. More...
| outdir
| Default search directory for output. More...
| intelpath
| Path to Intel Fortran Compiler (read from Paths.log). More...
| temps
| Tuple of data to be removed after job completion. More...
| incdirs
| List of include directories. More...
| libdirs
| List of library directories. More...
| libs
| List of actual libraries (by name) used during linking. More...
| copyfiles
| List of files to be copied to the output directory after finish. More...
| setarch
| Define the architecture for the build directly by using the keyword argument "arch". More...
| architecture
| Processor architecture.
| iniCompiler
| Executable batch script (including absolute system path) to set up the Intel Fortran Compiler. More...
| msvsc
| Default version of Microsoft visual studio used by the Intel Fortran Compiler. More...
| postcmd
| Post build command. More...
| buildname
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...

## Detailed Description

Base class for all Sphinx build events.

    Inherited class to automatically build a documentation using Sphinx.

Inherited from Make.

Definition at line 1467 of file Make.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Build.Make.Sphinx.__init__ | ( |  | self,
|  |  | args,
|  |  | kwargs
| ) |  |

    Initialization of sphinx class object.

Definition at line 1471 of file Make.py.

## Member Function Documentation

## ◆ create()

def PyXMake.Build.Make.Sphinx.create | ( |  | self,
|  |  | kwargs
| ) |  |

    Execute make command

Definition at line 1521 of file Make.py.

## ◆ Settings()

def PyXMake.Build.Make.Sphinx.Settings | ( |  | self,
|  |  | kwargs
| ) |  |

    Define environment variables for the default configuration file.

Definition at line 1511 of file Make.py.

## Member Data Documentation

## ◆ exe

PyXMake.Build.Make.Sphinx.exe

Executable of Sphinx.

Definition at line 1491 of file Make.py.

## ◆ incdirs

PyXMake.Build.Make.Sphinx.incdirs

Blank version of list containing library directories without initially specifying MKL.

Definition at line 1507 of file Make.py.

## ◆ MakeObjectKind

PyXMake.Build.Make.Sphinx.MakeObjectKind

String identifier of current instance.

Definition at line 1477 of file Make.py.

## ◆ path2exe

PyXMake.Build.Make.Sphinx.path2exe

Path to Sphinx executable.

Definition at line 1489 of file Make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Build/Make.py